<?php
if(!function_exists('theme_section_blog_featured_image')){
/**
 * The default template for displaying blog featured image in the pages
 */
function theme_section_blog_featured_image($type='full', $width = '', $height='', $frame = false, $effect= '', $single = false,  $adaptive_height=''){
	$thumbnail_id = get_post_thumbnail_id();
	if($single == false){
		$list_image = get_post_meta(get_the_ID(), '_list_image', true);
		if(is_array($list_image) && isset($list_image['value'])){
			$thumbnail_id = $list_image['value'];
		}
	}
	if (empty($thumbnail_id)) {
		return;
	}
	$image_src_array = wp_get_attachment_image_src($thumbnail_id,'full', true);

	switch($type){
		case 'full':
		case 'below':
			$width = $width - 2;

			if($frame && isset($width)){
				if($frame === true){
					$width = $width - 32;
				}else{
					$width = $width - intval($frame);
				}
			}
			if(empty($height)){
				if ($adaptive_height=='' || $adaptive_height=='default' ) $adaptive_height = theme_get_option('blog', 'adaptive_height');
				if($adaptive_height=="true"  && !empty($image_src_array[1])){
					$height = floor($width*($image_src_array[2]/$image_src_array[1]));
				}else{
					$height = theme_get_option('blog', 'single_fixed_height');
					if(!$single || empty($height)){
						$height = theme_get_option('blog', 'fixed_height');
					}
				}
			}
			break;
		case 'right':
		case 'left':
			if($width !== ''){
				$width = $width-2;
			} else {
				$width = theme_get_option('blog', 'left_width');
				$width = $width-2;
			}
			if($height !== ''){
				$height = $height-2;
			} else {
				$height = theme_get_option('blog', 'left_height');
				$height = $height-2;
			}
			break;
	}
	
	if(empty($effect)){
		$effect = theme_get_option('blog','effect');
	}
	$title = strip_tags(get_the_title());
	$alt_text=strip_tags(get_post_meta( $thumbnail_id, '_wp_attachment_image_alt', true ));
	if (empty($alt_text)) $alt_text=$title;
	
	$title_length= get_post_meta(get_the_id(), '_featured_img_title_length', true);
	if ($title_length==-1|| $title_length=='') $title_length=theme_get_option('blog', 'featured_img_title_length');

	if (!empty($title_length)) $title= wp_trim_words( $title, $title_length,  __(' ...','striking-r') );
	
	$image_src = theme_get_image_src(array('type'=>'attachment_id','value'=>$thumbnail_id), array($width, $height));
	$srcset=theme_get_retina_srcset( $image_src );

	$output = '';
	$output .= '<div class="image_styled entry_image" style="width:'.($width+2).'px">';
	$output .= '<div class="image_frame effect-'.$effect.'" ><div class="image_shadow_wrap">';
	if($single){
		if(theme_get_option('blog', 'featured_image_lightbox')){
			$fittoview = theme_get_option('blog', 'featured_image_lightbox_fitToView');
			
			if($fittoview !== ''){	
				$fittoview = ($fittoview == false)?' data-fittoview="false"':' data-fittoview="true"';
			} 
			if(theme_get_option('blog', 'featured_image_lightbox_gallery')){
				$post_id = get_queried_object_id();
				$output .= '<a class="image_icon_zoom lightbox" href="'.$image_src_array[0].'" data-fancybx-group="post-'.$post_id.'" title="'.$title.'"'.$fittoview.'>';
				$output .= '<img class="post_featured_image" width="'.$width.'" height="'.$height.'" data-thumbnail="'.$thumbnail_id.'" src="'.$image_src.'"'.$srcset.' alt="'.$alt_text.'" />';
				$output .= '</a>';

				$children = array(
					'post_parent' => $post_id,
					'post_status' => 'inherit',
					'post_type' => 'attachment',
					'post_mime_type' => 'image',
					'order' => 'ASC',
					'orderby' => 'menu_order ID',
					'numberposts' => -1,
					'offset' => ''
				);

				/* Get image attachments. If none, return. */
				$attachments = get_children( $children );
				if(!empty($attachments)){
					$output .= '<div class="hidden">';
					$post_thumbnail_id = get_post_thumbnail_id();
					foreach ( $attachments as $id => $attachment ) {
						$img_src = wp_get_attachment_image_src($id, 'full');
						if($id != $post_thumbnail_id){
						//$title = wptexturize( esc_html($attachment->post_excerpt) );
							$output .= '<a class="lightbox" href="'.$img_src[0].'" title="'.strip_tags(get_the_title()).'" data-fancybx-group="post-'.$post_id.'"'.$fittoview.'>'.$id.'</a>';
						}
					}
					$output .= '</div>';
				}
			}else{
				$output .= '<a class="image_icon_zoom lightbox" href="'.$image_src_array[0].'" title="'.$title.'"'.$fittoview.'>';
				$output .= '<img  class="post_featured_image" width="'.$width.'" height="'.$height.'" data-thumbnail="'.$thumbnail_id.'" src="'.$image_src.'"'.$srcset.' alt="'.$alt_text.'" />';
				$output .= '</a>';
			}
		} else {
			if($effect!='none'){
				$output .= '<a class="image_icon_zoom" href="#" title="'.$title.'"><img  class="post_featured_image" width="'.$width.'" height="'.$height.'" data-thumbnail="'.$thumbnail_id.'" src="'.$image_src.'"'.$srcset.' alt="'.$alt_text.'" /></a>';
			}else{
				$output .= '<a class="image_no_link" href="#" title="'.$title.'"><img  class="post_featured_image" width="'.$width.'" height="'.$height.'" data-thumbnail="'.$thumbnail_id.'" src="'.$image_src.'"'.$srcset.' alt="'.$alt_text.'" /></a>';
			}
		}
	} else {
		if(theme_get_option('blog', 'index_featured_image_lightbox')){
			$output .= '<a class="image_icon_zoom lightbox" href="'.$image_src_array[0].'" title="'.$title.'">';
			$output .= '<img  class="post_featured_image" width="'.$width.'" height="'.$height.'" data-thumbnail="'.$thumbnail_id.'" src="'.$image_src.'"'.$srcset.' alt="'.$alt_text.'" />';
			$output .= '</a>';
		} else {
			$title='';
			$output .= '<a class="image_icon_doc" href="'.get_permalink().'" title="'.$title.'">';
			$output .= '<img  class="post_featured_image" width="'.$width.'" height="'.$height.'" data-thumbnail="'.$thumbnail_id.'" src="'.$image_src.'"'.$srcset.' alt="'.$alt_text.'" />';
			$output .= '</a>';
		}
		
	}
	$output .= '</div></div>';
	$output .= '</div>';

	return $output;
}
}