<?php
/**
 * Single Product tabs
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/tabs/tabs.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 5.5.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Filter tabs and allow third parties to add their own.
 *
 * Each tab is an array containing title, callback and priority.
 *
 * @see woocommerce_default_product_tabs()
 */
$product_tabs = apply_filters( 'woocommerce_product_tabs', array() );

if ( ! empty( $product_tabs ) ) : ?>

	<?php if(theme_get_option('advanced','complex_class')){
		$tab_class="theme_tabs";
		$pane_class="theme_panes";
	} else {
		$tab_class="tabs";
		$pane_class="panes";
	}
	?>

	<div class="tabs_container">
		<ul class="<?php echo theme_sanitize_string($tab_class);?>" role="tablist">
			<?php foreach ( $product_tabs as $key => $product_tab ) : ?>

				<li class="<?php echo esc_attr( $key ); ?>_tab" id="tab-title-<?php echo esc_attr( $key ); ?>" role="tab" aria-controls="tab-<?php echo esc_attr( $key ); ?>">
					<a href="#tab-<?php echo theme_sanitize_string($key) ?>"><?php echo  wp_kses_post(apply_filters( 'woocommerce_product_' . $key . '_tab_title', $product_tab['title'], $key )) ?></a>
				</li>

			<?php endforeach; ?>
		</ul>

		<div class="<?php echo theme_sanitize_string($pane_class);?>">
		<?php foreach ( $product_tabs as $key => $product_tab ) : ?>

			<div class="panel entry-content" id="tab-<?php echo esc_attr($key) ?>" role="tabpanel" aria-labelledby="tab-title-<?php echo esc_attr( $key ); ?>">
				<?php 
				if ( isset( $product_tab['callback'] ) ) {
					call_user_func( $product_tab['callback'], $key, $product_tab );
				}?>
			</div>

		<?php endforeach; ?>
		<?php do_action( 'woocommerce_product_after_tabs' ); ?>
		</div>
	</div>

<?php endif; ?>